function PrimeUI:BuildArgs(trigger, triggerCode, args)
	if not self.triggerBuilderFunctions then self:BuildArgsBuilderList() end
	if self.triggerBuilderFunctions[trigger] then
		return self.triggerBuilderFunctions[trigger](self, trigger, triggerCode, args)
	else
		return {}
	end
end

function PrimeUI:BuildArgsBuilderList()
	self.triggerBuilderFunctions = nil
	self.triggerBuilderFunctions = {
		["EventTrigger"] = self.BuildEventTriggerArgs,
		["EffectAdded"] = self.BuildEffectAddedArgs,
		["EffectRemoved"] = self.BuildEffectRemovedArgs,

		-- Effect Group
		["EffectAdded_Group"] = self.BuildEffectAddedGroupArgs,

		-- Effect Target
		["EffectAdded_Target"] = self.BuildEffectAddedTargetArgs,

		-- Skill
		["Skills"] = self.BuildSkillArgs,
		["SkillReady"] = nil,

		-- Environment Chat
		["PartyChat"] = self.BuildPartyChatArgs,
		["SayChat"] = self.BuildSayChatArgs,
		["StandardChat"] = self.BuildStandardChatArgs,

		-- Combat Chat 
		["PlayerHits"] = self.BuildPlayerHitsArgs,
		["PlayerHeal"] = self.BuildPlayerHealArgs,
		["PlayerBenefit"] = self.BuildPlayerBenefitArgs,
		["EnemyHits"] = self.BuildEnemyHitsArgs,
		["CCBreak"] = self.BuildCCBreakArgs,

		-- Enivorment events
		["DefeatEvent"] = self.BuildDefeatEventArgs,

		-- Instance Fights
		["FightStart"] = self.BuildFightStartArgs,
		["FightPhase"] = self.BuildFightPhaseArgs,
		["FightEnd"] = self.BuildFightEndArgs,
	}
end

function PrimeUI:BuildEventTriggerArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = self.player:GetName(),
		Source = self.player:GetName(),

		-- Naming replacement args [external]
		Target = self.player:GetName(),
		Name = self.player:GetName(),
	}

	if self.args[triggerCode] and type(self.args[triggerCode]) == "table" then
		for k, v in pairs(self.args[triggerCode]) do
			eventArgs[k] = v
		end
	end

	return eventArgs
end

function PrimeUI:BuildEffectAddedArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = self.player:GetName(),
		Source = self.player:GetName(),
		-- Naming replacement args [external]
		EffectName = args:GetName(),
		Target = self.player:GetName(),
		Name = self.player:GetName(),

		-- Icon
		IconValue = args:GetIcon(),

		-- Time
		Trigger_Time = args:GetDuration() - (Turbine.Engine.GetGameTime() - args:GetStartTime()),
		Trigger_Max_Time = args:GetDuration(),
	}

	return eventArgs
end

function PrimeUI:BuildEffectRemovedArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = self.player:GetName(),
		Source = self.player:GetName(),
		-- Naming replacement args [external]
		EffectName = args:GetName(),
		Target = self.player:GetName(),
		Name = self.player:GetName(),

		-- Icon
		IconValue = args:GetIcon(),

		-- Time
		Trigger_Time = args:GetDuration() - (Turbine.Engine.GetGameTime() - args:GetStartTime()),
		Trigger_Max_Time = args:GetDuration(),
	}

	return eventArgs
end

function PrimeUI:BuildEffectAddedGroupArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.name,
		Source = args.name,
		-- Naming replacement args [external]
		EffectName = args.effect.Name,
		Target = args.name,
		Name = args.name,

		-- Icon
		IconValue = args.effect.Icon,

		-- Time
		Trigger_Time = args.effect.Duration - (Turbine.Engine.GetGameTime() - args.effect.StartTime),
		Trigger_Max_Time = args.effect.Duration,
	}

	return eventArgs
end

function PrimeUI:BuildEffectAddedTargetArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Target,
		Source = args.Target,
		-- Naming replacement args [external]
		EffectName = args.Name,
		Target = args.Target,
		Name = args.Target,

		-- Icon
		IconValue = args.Icon,

		-- Time
		Trigger_Time = args.Duration - (Turbine.Engine.GetGameTime() - args.StartTime),
		Trigger_Max_Time = args.Duration,
	}

	return eventArgs
end

function PrimeUI:BuildSkillArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),

		--Icon
		IconValue = args:GetSkillInfo():GetIconImageID(),

		-- Naming replacement args [internal]
		Trigger_Specific_Name = triggerCode,
		Source = self.player:GetName(),

		-- Naming replacement args [external]
		SkillName = triggerCode,
		Target = self.player:GetName(),
		Name = self.player:GetName(),

		Trigger_Time = args:GetResetTime() - Turbine.Engine.GetGameTime(),
		Trigger_Max_Time = args:GetCooldown(),
	}
	return eventArgs
end

function PrimeUI:BuildStandardChatArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = self.player:GetName(),
		Source = self.player:GetName(),
		-- Naming replacement args [external]
		Source = self.player:GetName(),
		Name = self.player:GetName(),
	}
	return eventArgs
end

function PrimeUI:BuildPartyChatArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Source,
		Source = args.Source or args.Source,
		-- Naming replacement args [external]
		Source = args.Source,
		Name = args.Source,
	}
	return eventArgs
end

function PrimeUI:BuildSayChatArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Source,
		Source = args.Source or args.Source,
		-- Naming replacement args [external]
		Source = args.Source,
		Name = args.Source,
	}
	return eventArgs
end

function PrimeUI:BuildEnemyHitsArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Target,
		Source = args.Source or args.Target,
		-- Naming replacement args [external]
		SkillName = args.SkillName,
		Source = args.Source,
		Target = args.Target,
		Name = args.Target,
	}
	return eventArgs
end

function PrimeUI:BuildPlayerHitsArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Target,
		Source = args.Source or args.Target,
		-- Naming replacement args [external]
		SkillName = args.SkillName,
		Source = args.Source,
		Target = args.Target,
		Name = args.Target,
	}
	return eventArgs
end

function PrimeUI:BuildPlayerHealArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Target,
		Source = args.Source or args.Target,
		-- Naming replacement args [external]
		SkillName = args.SkillName,
		Source = args.Source,
		Target = args.Target,
		Name = args.Target,
	}
	return eventArgs
end

function PrimeUI:BuildPlayerBenefitArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Target,
		Source = args.Source or args.Target,
		-- Naming replacement args [external]
		SkillName = args.SkillName,
		Source = args.Source,
		Target = args.Target,
		Name = args.Target,
	}
	return eventArgs
end

function PrimeUI:BuildCCBreakArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Target,
		Source = args.Culprit,
		-- Naming replacement args [external]
		source = args.Culprit,
		name = args.Target,
		culprit = args.Culprit,
		type = args.Type,
		target = args.Target,
	}
	return eventArgs
end

function PrimeUI:BuildDefeatEventArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Name,
		Source = args.Source or args.Source,
		-- Naming replacement args [external]
		SkillName = args.SkillName,
		Source = args.Source,
		Target = args.Name,
		Name = args.Name,
	}
	return eventArgs
end

function PrimeUI:BuildFightStartArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Boss_Name,
		Source = args.Source or args.Boss_Name,
		-- Naming replacement args [external]
		Source = args.Boss_Name,
		Tier = args.Boss_Tier,
		Name = args.Boss_Name,
	}
	return eventArgs
end

function PrimeUI:BuildFightPhaseArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Boss_Name,
		Source = args.Source or args.Boss_Name,
		-- Naming replacement args [external]
		Source = args.Boss_Name,
		Tier = args.Boss_Tier,
		Name = args.Boss_Name,
		Phase = args.Phase,
	}
	return eventArgs
end

function PrimeUI:BuildFightEndArgs(trigger, triggerCode, args)
	local eventArgs = {
		Trigger_Key = string.format("%s%s", trigger, triggerCode),
		-- Naming replacement args [internal]
		Trigger_Specific_Name = args.Boss_Name,
		Source = args.Source or args.Boss_Name,
		-- Naming replacement args [external]
		Source = args.Boss_Name,
		Tier = args.Boss_Tier,
		Name = args.Boss_Name,
	}
	return eventArgs
end